# Developer interface

## Client

```{eval-rst}
.. autoclass:: aiomqtt.Client
    :noindex:
    :special-members: __aenter__, __aexit__
```

## MessagesIterator

```{eval-rst}
.. autoclass:: aiomqtt.MessagesIterator
    :noindex:
    :special-members: __aiter__, __anext__, __len__
```

## Message

```{eval-rst}
.. autoclass:: aiomqtt.Message
    :noindex:
```

## Topic

```{eval-rst}
.. autoclass:: aiomqtt.Topic
    :noindex:
```

## Wildcard

```{eval-rst}
.. autoclass:: aiomqtt.Wildcard
    :noindex:
```
